@@ -69,12 +69,6 @@ class Account(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(Account, cls).__setup__()
-        cls._constraints += [
-            ('check_recursion', 'recursive_accounts'),
-            ]
-        cls._error_messages.update({
-                'recursive_accounts': 'You can not create recursive accounts!',
-                })
         cls._order.insert(0, ('code', 'ASC'))
 
     @staticmethod
@@ -108,6 +102,11 @@ class Account(ModelSQL, ModelView):
     def default_mandatory():
         return False
 
+    @classmethod
+    def validate(cls, accounts):
+        super(Account, cls).validate(accounts)
+        cls.check_recursion(accounts)
+
     def on_change_with_currency_digits(self, name=None):
         if self.currency:
             return self.currency.digits
@@ -130,24 +129,24 @@ class Account(ModelSQL, ModelView):
             id2account[account.id] = account
 
         line_query = Line.query_get()
-        cursor.execute('SELECT a.id, ' \
-                    'SUM((COALESCE(l.debit, 0) - COALESCE(l.credit, 0))), ' \
-                    'c.currency ' \
-                'FROM analytic_account_account a ' \
-                    'LEFT JOIN analytic_account_line l ' \
-                    'ON (a.id = l.account) ' \
-                    'LEFT JOIN account_move_line ml ' \
-                    'ON (ml.id = l.move_line) ' \
-                    'LEFT JOIN account_account aa ' \
-                    'ON (aa.id = ml.account) ' \
-                    'LEFT JOIN company_company c ' \
-                    'ON (c.id = aa.company) ' \
-                'WHERE a.type != \'view\' ' \
-                    'AND a.id IN (' + \
-                        ','.join(('%s',) * len(all_ids)) + ') ' \
-                    'AND ' + line_query + ' ' \
-                    'AND a.active ' \
-                'GROUP BY a.id, c.currency', all_ids)
+        cursor.execute('SELECT a.id, '
+                'SUM((COALESCE(l.debit, 0) - COALESCE(l.credit, 0))), '
+                    'c.currency '
+            'FROM analytic_account_account a '
+                'LEFT JOIN analytic_account_line l '
+                'ON (a.id = l.account) '
+                'LEFT JOIN account_move_line ml '
+                'ON (ml.id = l.move_line) '
+                'LEFT JOIN account_account aa '
+                'ON (aa.id = ml.account) '
+                'LEFT JOIN company_company c '
+                'ON (c.id = aa.company) '
+            'WHERE a.type != \'view\' '
+                'AND a.id IN (' +
+                    ','.join(('%s',) * len(all_ids)) + ') '
+                'AND ' + line_query + ' '
+                'AND a.active '
+            'GROUP BY a.id, c.currency', all_ids)
         account_sum = {}
         id2currency = {}
         for account_id, sum, currency_id in cursor.fetchall():
@@ -199,24 +198,24 @@ class Account(ModelSQL, ModelView):
             id2account[account.id] = account
 
         line_query = Line.query_get()
-        cursor.execute('SELECT a.id, ' \
-                    'SUM(COALESCE(l.' + name + ', 0)), ' \
-                    'c.currency ' \
-                'FROM analytic_account_account a ' \
-                    'LEFT JOIN analytic_account_line l ' \
-                    'ON (a.id = l.account) ' \
-                    'LEFT JOIN account_move_line ml ' \
-                    'ON (ml.id = l.move_line) ' \
-                    'LEFT JOIN account_account aa ' \
-                    'ON (aa.id = ml.account) ' \
-                    'LEFT JOIN company_company c ' \
-                    'ON (c.id = aa.company) ' \
-                'WHERE a.type != \'view\' ' \
-                    'AND a.id IN (' + \
-                        ','.join(('%s',) * len(ids)) + ') ' \
-                    'AND ' + line_query + ' ' \
-                    'AND a.active ' \
-                'GROUP BY a.id, c.currency', ids)
+        cursor.execute('SELECT a.id, '
+                'SUM(COALESCE(l.' + name + ', 0)), '
+                'c.currency '
+            'FROM analytic_account_account a '
+                'LEFT JOIN analytic_account_line l '
+                'ON (a.id = l.account) '
+                'LEFT JOIN account_move_line ml '
+                'ON (ml.id = l.move_line) '
+                'LEFT JOIN account_account aa '
+                'ON (aa.id = ml.account) '
+                'LEFT JOIN company_company c '
+                'ON (c.id = aa.company) '
+            'WHERE a.type != \'view\' '
+                'AND a.id IN (' +
+                    ','.join(('%s',) * len(ids)) + ') '
+                'AND ' + line_query + ' '
+                'AND a.active '
+            'GROUP BY a.id, c.currency', ids)
 
         id2currency = {}
         for account_id, sum, currency_id in cursor.fetchall():
@@ -325,7 +324,6 @@ class OpenChartAccount(Wizard):
 class AccountSelection(ModelSQL, ModelView):
     'Analytic Account Selection'
     __name__ = 'analytic_account.account.selection'
-    _rec_name = 'id'
 
     accounts = fields.Many2Many(
             'analytic_account.account-analytic_account.account.selection',
@@ -334,14 +332,16 @@ class AccountSelection(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(AccountSelection, cls).__setup__()
-        cls._constraints += [
-            ('check_root', 'root_account'),
-            ]
         cls._error_messages.update({
-                'root_account': 'Can not have many accounts with the same ' \
-                    'root or a missing mandatory root account!',
+                'root_account': ('Can not have many accounts with the same '
+                    'root or a missing mandatory root account on "%s".'),
                 })
 
+    @classmethod
+    def validate(cls, selections):
+        super(AccountSelection, cls).validate(selections)
+        cls.check_root(selections)
+
     @classmethod
     def check_root(cls, selections):
         "Check Root"
@@ -355,14 +355,14 @@ class AccountSelection(ModelSQL, ModelView):
             roots = []
             for account in selection.accounts:
                 if account.root.id in roots:
-                    return False
+                    cls.raise_user_error('root_account', (account.rec_name,))
                 roots.append(account.root.id)
             if Transaction().user:  # Root can by pass
                 for account in root_accounts:
                     if account.mandatory:
                         if not account.id in roots:
-                            return False
-        return True
+                            cls.raise_user_error('root_account',
+                                (account.rec_name,))
 
 
 class AccountAccountSelection(ModelSQL):
